@@ -1,4 +1,4 @@
-/* LOCKVC Version 3.4 (c) 1994,1995,1997 by Matthias Straub */
+/* LOCKVC Version 3.6 (c) 1994,1995,1997 by Matthias Straub */
 /* Original code written by Matthias Straub */
 /* 'Dotmorph' written by Lars Johannsen and Matthias Straub */
 /* shadow-password option added by Ed Beaumont */
@@ -40,7 +40,7 @@
 #include <vga.h>
 #include <termio.h>
      
-
+#include "lockvc.h"
 
 struct mfield 
 {
@@ -199,7 +199,7 @@ void minitpalette()
 
 void plotdots(struct mfield *feld)
      {
-	int i,x2,y2,z2,base;
+	int i,x2,y2,base;
 
 
 		
@@ -302,10 +302,9 @@ void restore(int what, struct mfield *feld)
 
 
 
-morphdots(int argc, char **argv)
+void morphdots(int argc, char **argv)
 {
     struct mfield this;
-    int i;
          
     if(argc ==3)
     {
@@ -490,7 +489,7 @@ void create_torus(int nr, int start, int length, int ra, int rb, struct mfield *
 void create_kegel(int nr, int start, int length, int radius, int hi, struct mfield *feld) 
 {
     int i, j,n,k,r;
-    float w,w1,w2;
+    float w,w2;
     
     n=(int)(sqrt(length));
     
