@@ -1,10 +1,13 @@
-/* LOCKVC Version 3.4 (c) 1994,1995,1997 by Matthias Straub */
+/* LOCKVC Version 3.6 (c) 1994,1995,1997 by Matthias Straub */
 /* shadow-password option added by Ed Beaumont */
 /* this file was released under GPL */
 /* see COPYING for details */
 
 #include <vga.h>
 #include <stdio.h>
+#include <stdlib.h>
+
+#include "lockvc.h"
 
 unsigned char *screen;
 unsigned char *rscreen;
@@ -13,7 +16,7 @@ unsigned char *escreen;
 unsigned short zuf=1777;
 unsigned short zufm=31317;
 
-draw_feuer()
+void draw_feuer()
      {
 	unsigned char *lscreen;
 	
@@ -33,7 +36,7 @@ draw_feuer()
 
      }
 
-feuer()
+void feuer()
 {
    int i;
 
