@@ -1,4 +1,4 @@
-/* LOCKVC Version 3.4 (c) 1994,1995,1997 by Matthias Straub */
+/* LOCKVC Version 3.6 (c) 1994,1995,1997 by Matthias Straub */
 /* shadow-password option added by Ed Beaumont */
 /* this file was released under GPL */
 /* see COPYING for details */
@@ -8,6 +8,8 @@
 #include <stdio.h>
 #include <math.h>
 
+#include "lockvc.h"
+
 struct vars 
 {
 char *lbuffer;
@@ -17,7 +19,7 @@ int xoff[200];
 int yoff[320];
 };
 
-draw_fudge(struct vars *this)
+void draw_fudge(struct vars *this)
      {
 	#include "bild.fudge"
 	unsigned char *lscreen;
@@ -40,10 +42,9 @@ draw_fudge(struct vars *this)
 	  }
      }
 
-fudge(int argc, char **argv)
+void fudge(int argc, char **argv)
 {
     #include "palette.fudge"
-    int xsiz, ysiz;
     int i;
     char t;
     struct vars this;
