@@ -1,5 +1,5 @@
 /* LOCKVC Version 3.0 (c) 1994, 1995, 1997 by Matthias Straub */
-/* Version 4.0.4 (c) 2001 Lawson Whitney */
+/* Version 4.0.5 (c) 2001 Lawson Whitney */
 /* shadow-password option added by Ed Beaumont */
 /* PAM option added by Lawson Whitney */
 /* integer math derived from a patch by Jeff Epler */
@@ -290,8 +290,12 @@ void vga_it()
 {
 	isconsole();
 	setreuid(0,0);
-	vga_init();
-
+	if (vga_init())
+	{
+	    syslog(LOG_ERR, "lockvc - vga_init failed.  Please check svgalib config.");
+	    fprintf(stderr, "lockvc - vga_init failed.  Please check svgalib config.");
+	    exit(16);
+	}	    
 	return;
 }	
 void main(int argc,char **argv)
